@@ -1,4 +1,4 @@
-# Copyright (c) 2022 CNES
+# Copyright (c) 2023 CNES
 #
 # All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
@@ -9,7 +9,15 @@ pyinterp
 from . import geodetic, geohash, version
 from ._geohash import GeoHash
 from .binning import Binning1D, Binning2D
-from .core import Axis, AxisInt64, TemporalAxis, dateutils
+from .core import (
+    Axis,
+    AxisInt64,
+    RadialBasisFunction,
+    TemporalAxis,
+    WindowFunction,
+    dateutils,
+    interpolate1d,
+)
 from .grid import Grid2D, Grid3D, Grid4D
 from .histogram2d import Histogram2D
 from .interpolator.bicubic import bicubic
@@ -54,12 +62,15 @@ __all__ = [
     'Grid3D',
     'Grid4D',
     'Histogram2D',
+    'interpolate1d',
     'Orbit',
     'Pass',
     'quadrivariate',
+    'RadialBasisFunction',
     'RTree',
     'StreamingHistogram',
     'Swath',
     'TemporalAxis',
     'trivariate',
+    'WindowFunction',
 ]
