@@ -1,4 +1,4 @@
-// Copyright (c) 2022 CNES
+// Copyright (c) 2023 CNES
 //
 // All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
@@ -1084,6 +1084,30 @@ Returns:
     The intersection between this linestring and the other linestring.
 )__doc__",
            py::call_guard<py::gil_scoped_release>())
+      .def(
+          "simplify",
+          [](const geodetic::LineString &self, const double tolerance,
+             const std::string &strategy,
+             const std::optional<geodetic::Spheroid> &spheroid)
+              -> geodetic::LineString {
+            return self.simplify(tolerance, parse_distance_strategy(strategy),
+                                 spheroid);
+          },
+          py::arg("tolerance"), py::arg("strategy") = "thomas",
+          py::arg("wgs") = std::nullopt,
+          R"__doc__(
+Simplifies this linestring using the Douglas-Peucker algorithm.
+
+Args:
+    tolerance: The tolerance to use.
+    strategy: The distance strategy to use. This parameter can take the values
+        ``andoyer``, ``thomas`` or ``vincenty``. Defaults to ``thomas``.
+    wgs: The World Geodetic System to use. Defaults to WGS84.
+
+Returns:
+    The simplified linestring.
+)__doc__",
+          py::call_guard<py::gil_scoped_release>())
       .def(py::pickle(
           [](const geodetic::LineString &self) { return self.getstate(); },
           [](const py::tuple &state) {
@@ -1176,7 +1200,15 @@ Returns:
 }
 
 static auto init_geodetic_rtree(py::module &m) {
-  py::class_<geodetic::RTree>(m, "RTree")
+  py::class_<geodetic::RTree>(
+      m, "RTree",
+      "RTree(self, spheroid: Optional[pyinterp.core.geodetic.Spheroid] = None)"
+      R"__doc__(
+R*Tree spatial index.
+
+Args:
+    spheroid: WGS of the coordinate system used to calculate the distance.
+)__doc__")
       .def(py::init<std::optional<geodetic::Spheroid>>(),
            py::arg("spheroid") = std::nullopt)
       .def(
@@ -1265,6 +1297,8 @@ Args:
         true, the method ensures that the neighbors found are located around
         the point of interest. In other words, this parameter ensures that the
         calculated values will not be extrapolated. Defaults to ``true``.
+    within: If true, the method ensures that the neighbors found are located
+        within the point of interest. Defaults to ``false``.
     num_threads: The number of threads to use for the computation. If 0 all
         CPUs are used. If 1 is given, no parallel computing code is used at
         all, which is useful for debugging. Defaults to ``0``.
@@ -1290,20 +1324,16 @@ Args:
     k: The number of nearest neighbors to be used for calculating the
         interpolated value. Defaults to ``9``.
     rbf: The radial basis function, based on the radius, r, given by
-    the
-        distance between points. Default to
+        the distance between points. Default to
         :py:attr:`pyinterp.core.RadialBasisFunction.Multiquadric`.
     epsilon: Adjustable constant for gaussian or multiquadrics
-    functions.
-        Default to the average distance between nodes.
+        functions. Default to the average distance between nodes.
     smooth: Values greater than zero increase the smoothness of the
         approximation.
     within: If true, the method ensures that the neighbors found are
-    located
-        around the point of interest. Defaults to ``true``.
+        located around the point of interest. Defaults to ``true``.
     num_threads: The number of threads to use for the computation. If 0
-    all CPUs
-        are used. If 1 is given, no parallel computing code is used at
+        all CPUs are used. If 1 is given, no parallel computing code is used at
         all, which is useful for debugging. Defaults to ``0``.
 Returns:
     The interpolated value and the number of neighbors used for the
