@@ -1,4 +1,4 @@
-# Copyright (c) 2022 CNES
+# Copyright (c) 2023 CNES
 #
 # All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
@@ -8,9 +8,9 @@ RTree spatial index
 """
 from typing import Optional, Tuple
 
-import numpy as np
+import numpy
 
-from . import core, geodetic
+from . import core, geodetic, interface
 
 
 class RTree:
@@ -29,15 +29,15 @@ class RTree:
 
     def __init__(self,
                  system: Optional[geodetic.Spheroid] = None,
-                 dtype: Optional[np.dtype] = None,
+                 dtype: Optional[numpy.dtype] = None,
                  ndims: int = 3):
         """Initialize a new R*Tree."""
-        dtype = dtype or np.dtype('float64')
+        dtype = dtype or numpy.dtype('float64')
         if ndims < 3:
             raise ValueError('ndims must be >= 3')
-        if dtype == np.dtype('float64'):
+        if dtype == numpy.dtype('float64'):
             self._instance = getattr(core, f'RTree{ndims}DFloat64')(system)
-        elif dtype == np.dtype('float32'):
+        elif dtype == numpy.dtype('float32'):
             self._instance = getattr(core, f'RTree{ndims}DFloat32')(system)
         else:
             raise ValueError(f'dtype {dtype} not handled by the object')
@@ -67,7 +67,8 @@ class RTree:
         """Returns true if the tree is not empty."""
         return self._instance.__bool__()
 
-    def packing(self, coordinates: np.ndarray, values: np.ndarray) -> None:
+    def packing(self, coordinates: numpy.ndarray,
+                values: numpy.ndarray) -> None:
         """The tree is created using packing algorithm (The old data is erased
         before construction.)
 
@@ -83,7 +84,8 @@ class RTree:
         """
         self._instance.packing(coordinates, values)
 
-    def insert(self, coordinates: np.ndarray, values: np.ndarray) -> None:
+    def insert(self, coordinates: numpy.ndarray,
+               values: numpy.ndarray) -> None:
         """Insert new data into the search tree.
 
         Args:
@@ -98,20 +100,57 @@ class RTree:
         """
         self._instance.insert(coordinates, values)
 
+    def value(self,
+              coordinates: numpy.ndarray,
+              radius: Optional[float] = None,
+              k: int = 4,
+              within: bool = True,
+              num_threads: int = 0) -> Tuple[numpy.ndarray, numpy.ndarray]:
+        """Get the coordinates and values for the K-nearest neighbors of a
+        given point.
+
+        Args:
+            coordinates: a matrix ``(n, ndims)`` where ``n`` is the number of
+                observations and ``ndims`` is the number of coordinates in
+                order: longitude and latitude in degrees, altitude in meters.
+                If ndims is equal to 2 then the altitude is considered to be
+                constant and equal to zero.
+            radius (optional): The maximum distance in meters to search for
+                neighbors. If not set, the search is performed on all the
+                neighbors.
+            k: The number of nearest neighbors to return.
+            within: if true, the method returns the k nearest neighbors if the
+                point is within by its neighbors.
+            num_threads: The number of threads to use for the computation. If 0
+                all CPUs are used. If 1 is given, no parallel computing code is
+                used at all, which is useful for debugging. Defaults to ``0``.
+
+        Returns:
+            A tuple containing the coordinates and values of the K-nearest
+            neighbors of the given point.
+
+        .. note::
+            The matrix containing the coordinates of the neighbors is a matrix
+            of dimension ``(k, n)`` where ``n`` is equal to 2 if the provided
+            coordinates matrix defines only longitude and latitude, and 3 if the
+            defines longitude, latitude and altitude.
+        """
+        return self._instance.value(coordinates, radius, k, within,
+                                    num_threads)
+
     def query(self,
-              coordinates: np.ndarray,
-              k: Optional[int] = 4,
-              within: Optional[bool] = True,
-              num_threads: Optional[int] = 0) -> Tuple[np.ndarray, np.ndarray]:
+              coordinates: numpy.ndarray,
+              k: int = 4,
+              within: bool = True,
+              num_threads: int = 0) -> Tuple[numpy.ndarray, numpy.ndarray]:
         """Search for the nearest K nearest neighbors of a given point.
 
         Args:
             coordinates: a matrix ``(n, ndims)`` where ``n`` is the number of
                 observations and ``ndims`` is the number of coordinates in
-                order: longitude and latitude in degrees, altitude in meters and
-                then the other coordinates defined in Euclidean space if
-                ``dims`` > 3. If the shape of the matrix is ``(n, ndims)`` then
-                the method considers the altitude constant and equal to zero.
+                order: longitude and latitude in degrees, altitude in meters.
+                If ndims is equal to 2 then the altitude is considered to be
+                constant and equal to zero.
             k: The number of nearest neighbors to be searched. Defaults to
                 ``4``.
             within: If true, the method ensures that the neighbors found are
@@ -131,22 +170,21 @@ class RTree:
 
     def inverse_distance_weighting(
             self,
-            coordinates: np.ndarray,
+            coordinates: numpy.ndarray,
             radius: Optional[float] = None,
-            k: Optional[int] = 9,
-            p: Optional[int] = 2,
-            within: Optional[bool] = True,
-            num_threads: Optional[int] = 0) -> Tuple[np.ndarray, np.ndarray]:
+            k: int = 9,
+            p: int = 2,
+            within: bool = True,
+            num_threads: int = 0) -> Tuple[numpy.ndarray, numpy.ndarray]:
         """Interpolation of the value at the requested position by inverse
         distance weighting method.
 
         Args:
             coordinates: a matrix ``(n, ndims)`` where ``n`` is the number of
                 observations and ``ndims`` is the number of coordinates in
-                order: longitude and latitude in degrees, altitude in meters and
-                then the other coordinates defined in Euclidean space if
-                ``dims`` > 3. If the shape of the matrix is ``(n, ndims)`` then
-                the method considers the altitude constant and equal to zero.
+                order: longitude and latitude in degrees, altitude in meters.
+                If ndims is equal to 2 then the altitude is considered to be
+                constant and equal to zero.
             radius: The maximum radius of the search (m). Defaults The maximum
                 distance between two points.
             k: The number of nearest neighbors to be used for calculating the
@@ -168,24 +206,23 @@ class RTree:
 
     def radial_basis_function(
             self,
-            coordinates: np.ndarray,
+            coordinates: numpy.ndarray,
             radius: Optional[float] = None,
-            k: Optional[int] = 9,
+            k: int = 9,
             rbf: Optional[str] = None,
             epsilon: Optional[float] = None,
-            smooth: Optional[float] = 0,
-            within: Optional[bool] = True,
-            num_threads: Optional[int] = 0) -> Tuple[np.ndarray, np.ndarray]:
+            smooth: float = 0,
+            within: bool = True,
+            num_threads: int = 0) -> Tuple[numpy.ndarray, numpy.ndarray]:
         """Interpolation of the value at the requested position by radial basis
         function interpolation.
 
         Args:
             coordinates: a matrix ``(n, ndims)`` where ``n`` is the number of
                 observations and ``ndims`` is the number of coordinates in
-                order: longitude and latitude in degrees, altitude in meters and
-                then the other coordinates defined in Euclidean space if
-                ``dims`` > 3. If the shape of the matrix is ``(n, ndims)`` then
-                the method considers the altitude constant and equal to zero.
+                order: longitude and latitude in degrees, altitude in meters.
+                If ndims is equal to 2 then the altitude is considered to be
+                constant and equal to zero.
             radius: The maximum radius of the search (m). Defaults The maximum
                 distance between two points.
             k: The number of nearest neighbors to be used for calculating the
@@ -220,29 +257,20 @@ class RTree:
             The interpolated value and the number of neighbors used in the
             calculation.
         """
-        adjustable = ['gaussian', 'inverse_multiquadric', 'multiquadric']
-        non_adjustable = ['cubic', 'linear', 'thin_plate']
-        rbf = rbf or adjustable[-1]
-        if epsilon is not None and rbf in non_adjustable:
-            raise ValueError(
-                f"epsilon must be None for {', '.join(non_adjustable)} RBF")
-        if rbf not in adjustable + non_adjustable:
-            raise ValueError(f'Radial basis function {rbf!r} is not defined')
-        rbf = ''.join(item.capitalize() for item in rbf.split('_'))
-
         return self._instance.radial_basis_function(
-            coordinates, radius, k, getattr(core.RadialBasisFunction, rbf),
-            epsilon, smooth, within, num_threads)
+            coordinates, radius, k,
+            interface._core_radial_basis_function(rbf, epsilon), epsilon,
+            smooth, within, num_threads)
 
     def window_function(
             self,
-            coordinates: np.ndarray,
+            coordinates: numpy.ndarray,
             radius: float,
-            k: Optional[int] = 9,
+            k: int = 9,
             wf: Optional[str] = None,
             arg: Optional[float] = None,
-            within: Optional[bool] = True,
-            num_threads: Optional[int] = 0) -> Tuple[np.ndarray, np.ndarray]:
+            within: bool = True,
+            num_threads: int = 0) -> Tuple[numpy.ndarray, numpy.ndarray]:
         """Interpolation of the value at the requested position by window
         function.
 
@@ -262,10 +290,9 @@ class RTree:
         Args:
             coordinates: a matrix ``(n, ndims)`` where ``n`` is the number of
                 observations and ``ndims`` is the number of coordinates in
-                order: longitude and latitude in degrees, altitude in meters and
-                then the other coordinates defined in Euclidean space if
-                ``dims`` > 3. If the shape of the matrix is ``(n, ndims)`` then
-                the method considers the altitude constant and equal to zero.
+                order: longitude and latitude in degrees, altitude in meters.
+                If ndims is equal to 2 then the altitude is considered to be
+                constant and equal to zero.
             radius: The maximum radius of the search (m).
             k: The number of nearest neighbors to be used for calculating the
                 interpolated value. Defaults to ``9``.
@@ -325,50 +352,9 @@ class RTree:
             The interpolated value and the number of neighbors used in the
             calculation.
         """
-        wf = wf or 'blackman'
-        if wf not in [
-                'blackman',
-                'blackman_harris',
-                'boxcar',
-                'flattop',
-                'gaussian',
-                'hamming',
-                'lanczos',
-                'nuttall',
-                'parzen',
-                'parzen_swot',
-        ]:
-            raise ValueError(f'Window function {wf!r} is not defined')
-
-        if wf in ['gaussian', 'lanczos', 'parzen']:
-            if arg is None:
-                defaults = dict(gaussian=None, lanczos=1, parzen=0)
-                arg = defaults[wf]
-
-            if wf == 'lanczos' and arg < 1:  # type: ignore
-                raise ValueError(
-                    f'The argument of the function {wf!r} must be '
-                    'greater than 1')
-
-            if wf == 'parzen' and arg < 0:  # type: ignore
-                raise ValueError(
-                    f'The argument of the function {wf!r} must be '
-                    'greater than 0')
-
-            if wf == 'gaussian' and arg is None:
-                raise ValueError(
-                    f'The argument of the function {wf!r} must be '
-                    'specified')
-        else:
-            if arg is not None:
-                raise ValueError(f'The function {wf!r} does not support the '
-                                 'optional argument')
-
-        wf = ''.join(item.capitalize() for item in wf.split('_'))
-
-        return self._instance.window_function(coordinates, radius, k,
-                                              getattr(core.WindowFunction, wf),
-                                              arg, within, num_threads)
+        return self._instance.window_function(
+            coordinates, radius, k, interface._core_window_function(wf, arg),
+            arg, within, num_threads)
 
     def __getstate__(self) -> Tuple:
         """Return the state of the object for pickling purposes.
