@@ -1,4 +1,4 @@
-# Copyright (c) 2022 CNES
+# Copyright (c) 2023 CNES
 #
 # All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "2022.9.1"
+    return "2023.1.0"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "06 September 2022"
+    return "13 January 2023"
